fnss.topologies.topology.DirectedTopology.copy — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.DirectedTopology.copy

`DirectedTopology.` `copy`()

  Return a copy of the topology.

  Returns : | topology : DirectedTopology A copy of the topology.

  See also

  `to_undirected`
    return a undirected copy of the topology.

  Notes

  This makes a complete copy of the topology including all of the node or edge attributes.

  Examples

      >>> topo = DirectedTopology()
      >>> topo.add_path([0,1,2,3])
      >>> copied_topo = topo.copy()

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »